@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2018 Purism SPC
+ *               2025 Phosh.mobi e.V.
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -10,7 +11,6 @@
 
 #include "phosh-config.h"
 
-#include "log.h"
 #include "shell-priv.h"
 #include "phosh-wayland.h"
 #include "wall-clock.h"
@@ -36,28 +36,6 @@ quit (gpointer unused)
 }
 
 
-static gboolean
-on_sigusr1_signal (gpointer unused)
-{
-  static gboolean logall = FALSE;
-
-  if (logall) {
-    const char *domains;
-
-    domains = g_getenv ("G_MESSAGES_DEBUG");
-    g_message ("Enabling messages for %s", domains);
-    phosh_log_set_log_domains (domains);
-    logall = FALSE;
-  } else {
-    g_message ("Enabling all log messages");
-    phosh_log_set_log_domains ("all");
-    logall = TRUE;
-  }
-
-  return G_SOURCE_CONTINUE;
-}
-
-
 static gboolean
 on_shutdown_signal (gpointer unused)
 {
@@ -153,8 +131,6 @@ main (int argc, char *argv[])
   if (version)
     print_version ();
 
-  phosh_log_set_log_domains (g_getenv ("G_MESSAGES_DEBUG"));
-
   textdomain (GETTEXT_PACKAGE);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
@@ -164,7 +140,6 @@ main (int argc, char *argv[])
 
   g_unix_signal_add (SIGTERM, on_shutdown_signal, NULL);
   g_unix_signal_add (SIGINT, on_shutdown_signal, NULL);
-  g_unix_signal_add (SIGUSR1, on_sigusr1_signal, NULL);
 
   wall_clock = get_clock ();
   phosh_wall_clock_set_default (wall_clock);
@@ -181,6 +156,5 @@ main (int argc, char *argv[])
 
   gtk_main ();
 
-  phosh_log_set_log_domains (NULL);
   return EXIT_SUCCESS;
 }
