@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023 Guido Günther <agx@sigxcpu.org>
+ * Copyright (C) 2023 Phosh.mobi e.V.
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
@@ -17,5 +17,7 @@ G_BEGIN_DECLS
 G_DECLARE_FINAL_TYPE (PhoshPowerMenu, phosh_power_menu, PHOSH, POWER_MENU, PhoshSystemModalDialog)
 
 PhoshPowerMenu *phosh_power_menu_new (PhoshMonitor *monitor);
+void            phosh_power_menu_set_show_suspend (PhoshPowerMenu *self, gboolean show_suspend);
+gboolean        phosh_power_menu_get_show_suspend (PhoshPowerMenu *self);
 
 G_END_DECLS
